require 'spec_helper'

describe Textmerge::Merge do
  merge = ''

  before(:each) do
    options = {:template => "template.txt",:input=>"in.txt", :output=> "out.txt"}
    merge = Textmerge::Merge.new(options)
  end

  let(:data) { "{1:First question} This is some text to ignore
                this would be some additional text, and then {2:Second question}
                and we have some more text before ending {3:Third question}
                Links are {1}, {2}, {3}." }

  let(:result) {{1=>"First question",2=>"Second question",3=>"Third question"}}

  let(:answers) {{1=>"Answer 1", 2=>"answer 2",3=>"answer 3"}}

  let(:output) { "Answer 1 This is some text to ignore
                this would be some additional text, and then answer 2
                and we have some more text before ending answer 3
                Links are Answer 1, answer 2, answer 3." }
  let(:printed) {"1:First question\n2:Second question\n3:Third question\n" }


  context "when reading from input" do
    it "reads from an input file and output a hash of responses" do
      test_file_path = File.join(File.dirname(__FILE__), "test_input.txt")
      expect(merge.get_responses_from_input_file(test_file_path)).to eq answers
    end

    it "reads a file and return an array of questions" do
      expect(merge.get_requests(data)).to eq(result)
      expect(merge.get_requests(data)[2]).to eq("Second question")
    end

    it "orders questions properly" do
      text = "{2:Second question} and the {1:First question}"
      expect(merge.get_requests(text)[1]).to eq("First question")
    end

    it "raises an exception when there is a blank question" do

    end
  end

  context "when handling input" do
    it "builds responses from our hash of questions" do
      Textmerge::Merge.any_instance.stub(:ask_basic_question).and_return("Answer 1")
      expect(merge.get_responses({1=>"Question 1"})).to eq({1=>"Answer 1"})
    end

    it "creates a list of questions from the template file" do
      expect(merge.build_input_file(data)).to eq printed
    end

    it "create an input file name from the original template" do
      expect(merge.name_input_file("template.txt")).to eq "template-input.txt"
    end

  end
end

